From b98af7060b907cb28c2ee3e6508f9a3c5a051172 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:02:47 +0200
Subject: [PATCH 01/10] removed allowUnfree redundancy
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
nixos/nvidia.nix | 1 -
1 file changed, 1 deletion(-)
diff --git a/nixos/nvidia.nix b/nixos/nvidia.nix
index e14e658..7ea1c62 100644
--- a/nixos/nvidia.nix
+++ b/nixos/nvidia.nix
@@ -39,7 +39,6 @@ in {
# Configuration for proprietary packages
nixpkgs.config = {
nvidia.acceptLicense = true;
- allowUnfree = true; # Simplified from specific allowUnfreePredicate
};
# Nvidia configuration
From a07b0a38ac373c58846006b7ac3178f01b096644 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:24:00 +0200
Subject: [PATCH 03/10] garbage collect cleans more stuff
You might want to remove the logging
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/scripts/nixy/default.nix | 13 +++++++++++--
1 file changed, 11 insertions(+), 2 deletions(-)
diff --git a/home/scripts/nixy/default.nix b/home/scripts/nixy/default.nix
index b51aec8..51f1c13 100644
--- a/home/scripts/nixy/default.nix
+++ b/home/scripts/nixy/default.nix
@@ -55,8 +55,17 @@ let
elif [[ $1 == "update" ]];then
cd ${configDirectory} && nix flake update
elif [[ $1 == "gc" ]];then
- cd ${configDirectory} && sudo nix-collect-garbage -d
- cd ${configDirectory} && nix-collect-garbage -d
+ echo "Starting Nix garbage collection..."
+ cd ${configDirectory} && \
+ echo "Cleaning up system garbage..." && \
+ sudo nix-collect-garbage -d && \
+ echo "Cleaning up user garbage..." && \
+ nix-collect-garbage -d && \
+ echo "Collecting garbage from Nix store..." && \
+ nix-store --gc && \
+ echo "Optimizing Nix store..." && \
+ nix-store --optimise
+ echo "Nix garbage collection complete."
elif [[ $1 == "cb" ]];then
sudo /run/current-system/bin/switch-to-configuration boot
elif [[ $1 == "listgen" ]];then
From 172205b6134d92e5b3ac9267f9e8e2e8adedf3c9 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:29:32 +0200
Subject: [PATCH 04/10] added new options when right-clicking in Thunar
Open Terminal Here and Extract here options
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/programs/thunar/default.nix | 27 +++++++++++++++++++++++++++
1 file changed, 27 insertions(+)
diff --git a/home/programs/thunar/default.nix b/home/programs/thunar/default.nix
index c4e70f4..78a7ff2 100644
--- a/home/programs/thunar/default.nix
+++ b/home/programs/thunar/default.nix
@@ -108,4 +108,31 @@ in {
'';
+
+ xdg.configFile."Thunar/uca.xml".text = ''
+
+
+
+ utilities-terminal
+ Open Terminal Here
+ 1700000000000001
+ kitty -d %f
+ Opens Kitty terminal in the selected folder
+ *
+
+
+
+
+
+ Extract here
+
+ 1689618425925956-3
+ xarchiver -x . %f
+ Extracts the archive into the directory it is located in.
+ *
+ *.tar.bz2;*.tar.gz;*.tar.xz;*.tar.Z;*.tar;*.taz;*.tb2;*.tbz;*.tbz2;*.tgz;*.txz;*.zip;*.bz2;*.docx;*.apk;*.gz;*.odt;
+
+
+
+ '';
}
From 1e68496efe964e30e85b9001365fa22fd751a92d Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:33:03 +0200
Subject: [PATCH 05/10] added overrideGpg to lazygit
This allows to remove the flickering/prompting from lazygit when
committing a signed commit.
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/programs/lazygit/default.nix | 1 +
1 file changed, 1 insertion(+)
diff --git a/home/programs/lazygit/default.nix b/home/programs/lazygit/default.nix
index 942567d..a330a09 100644
--- a/home/programs/lazygit/default.nix
+++ b/home/programs/lazygit/default.nix
@@ -16,6 +16,7 @@ in {
update.method = "never";
git = {
commit.signOff = true;
+ overrideGpg = true;
parseEmoji = true;
};
gui = {
From 8fdab8a9ccd8546ee1241d816d20d314f8fa6697 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:43:08 +0200
Subject: [PATCH 06/10] Hyprlock tweak, removed useless options and added QoL
tweaks
This can be seen as a subjective change and you can ignore it if it does
not fit into your idea of nixy.
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/system/hyprlock/default.nix | 26 +++++---------------------
1 file changed, 5 insertions(+), 21 deletions(-)
diff --git a/home/system/hyprlock/default.nix b/home/system/hyprlock/default.nix
index 33eba70..e6313e7 100644
--- a/home/system/hyprlock/default.nix
+++ b/home/system/hyprlock/default.nix
@@ -1,9 +1,6 @@
# Hyprlock is a lockscreen for Hyprland
-{
- config,
- lib,
- ...
-}: let
+{ config, lib, ... }:
+let
foreground = "rgba(${config.theme.textColorOnWallpaper}ee)";
font = config.stylix.fonts.serif.name;
in {
@@ -11,18 +8,11 @@ in {
enable = true;
settings = {
general = {
- no_fade_in = false;
- disable_loading_bar = false;
+ ignore_empty_input = true;
+ hide_cursor = true;
};
- background = {
- monitor = "";
- blur_passes = 0;
- contrast = 0.8916;
- brightness = 0.7172;
- vibrancy = 0.1696;
- vibrancy_darkness = 0.0;
- };
+ background = { brightness = 0.7172; };
label = [
{
@@ -52,10 +42,6 @@ in {
monitor = "";
text = " $USER";
color = foreground;
- outline_thickness = 2;
- dots_size = 0.2; # Scale of input-field height, 0.2 - 0.8
- dots_spacing = 0.2; # Scale of dots' absolute size, 0.0 - 1.0
- dots_center = true;
font_size = 18;
font_family = font + " Bold";
position = "0, -180";
@@ -66,7 +52,6 @@ in {
# INPUT FIELD
input-field = lib.mkForce {
- monitor = "";
size = "300, 60";
outline_thickness = 2;
dots_size = 0.2; # Scale of input-field height, 0.2 - 0.8
@@ -78,7 +63,6 @@ in {
fade_on_empty = false;
font_family = font + " Bold";
placeholder_text = "🔒 Enter Password";
- hide_input = false;
position = "0, -250";
halign = "center";
valign = "center";
From f110213bb026fa37c2a863cb0f8d4dead59375e7 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:53:27 +0200
Subject: [PATCH 07/10] removed useless packages for screenshot
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/scripts/screenshot/default.nix | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/home/scripts/screenshot/default.nix b/home/scripts/screenshot/default.nix
index 8a7bac3..78ebb11 100644
--- a/home/scripts/screenshot/default.nix
+++ b/home/scripts/screenshot/default.nix
@@ -28,5 +28,5 @@
fi
'';
in {
- home.packages = [pkgs.hyprshot screenshot pkgs.slurp pkgs.grim pkgs.grimblast];
+ home.packages = [ screenshot pkgs.grim pkgs.grimblast ];
}
From bd2c7dfc25f8afc13c07d22785b6c2643bb992ca Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:55:22 +0200
Subject: [PATCH 08/10] Fix not needed anymore and allows rounding on all apps
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/system/hyprland/default.nix | 2 --
1 file changed, 2 deletions(-)
diff --git a/home/system/hyprland/default.nix b/home/system/hyprland/default.nix
index 693a968..4db4e28 100644
--- a/home/system/hyprland/default.nix
+++ b/home/system/hyprland/default.nix
@@ -177,8 +177,6 @@ in {
"dimaround, class:^(polkit-gnome-authentication-agent-1)$"
"dimaround, class:^(zen)$, title:^(File Upload)$"
- # fix xwayland apps
- "rounding 0, xwayland:1"
"center, class:^(.*jetbrains.*)$, title:^(Confirm Exit|Open Project|win424|win201|splash)$"
"size 640 400, class:^(.*jetbrains.*)$, title:^(splash)$"
];
From f9c4bd1f9960ae30a52a8c91ac08dfe799bc19cd Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:57:16 +0200
Subject: [PATCH 09/10] removed caffeine in tofi as Hypridle is not used
anymore
This is another change that can be ignored as hypridle can be commented
out and used again in nixy (even though it's quite clunky)
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/scripts/system/default.nix | 4 ----
1 file changed, 4 deletions(-)
diff --git a/home/scripts/system/default.nix b/home/scripts/system/default.nix
index 0acf058..004c584 100644
--- a/home/scripts/system/default.nix
+++ b/home/scripts/system/default.nix
@@ -79,7 +79,6 @@
# pkill tofi
else
options=(
- " Caffeine"
" Night-shift"
" Nixy"
" Hyprpicker"
@@ -91,9 +90,6 @@
selected=''${selected:2}
case $selected in
- "Caffeine")
- caffeine
- ;;
"Night-shift")
night-shift
;;
From 97ff9eb09ef98c0f250905158e350ceffa141c96 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 16:01:11 +0200
Subject: [PATCH 10/10] removed useless options in wofi
Same as last commit, you probably did it on purpose to allow easier
modification later on.
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/system/wofi/default.nix | 14 +-------------
1 file changed, 1 insertion(+), 13 deletions(-)
diff --git a/home/system/wofi/default.nix b/home/system/wofi/default.nix
index 341e1cd..f2d35f9 100644
--- a/home/system/wofi/default.nix
+++ b/home/system/wofi/default.nix
@@ -24,25 +24,13 @@ in {
show = "drun";
prompt = "Apps";
normal_window = true;
- layer = "top";
- height = "325px";
- orientation = "vertical";
- halign = "fill";
- line_wrap = "off";
- dynamic_lines = false;
+ height = 325;
allow_images = true;
image_size = 24;
- exec_search = false;
- hide_search = false;
- parse_search = false;
insensitive = true;
hide_scroll = true;
no_actions = true;
- sort_order = "default";
gtk_dark = true;
- filter_rate = 100;
- key_expand = "Tab";
- key_exit = "Escape";
};
style =
From f70a139bd7e9ba1d197c4b8e5ca0da8917e15f07 Mon Sep 17 00:00:00 2001
From: Purin <118902463+Dylouwu@users.noreply.github.com>
Date: Mon, 25 Aug 2025 15:12:35 +0200
Subject: [PATCH 02/10] changed nixy from having an upgrade to a test option
This allows you to test the configuration without building it, where as
upgrade is useless with flakes (and can be confusing with update)
Signed-off-by: Purin <118902463+Dylouwu@users.noreply.github.com>
---
home/scripts/nixy/default.nix | 24 +++++++++---------------
1 file changed, 9 insertions(+), 15 deletions(-)
diff --git a/home/scripts/nixy/default.nix b/home/scripts/nixy/default.nix
index 884cdbc..b51aec8 100644
--- a/home/scripts/nixy/default.nix
+++ b/home/scripts/nixy/default.nix
@@ -1,20 +1,15 @@
# - ## Nixy
#-
#- Nixy is a simple script that I use to manage my NixOS system. It's a simple script that provides a menu to rebuild, upgrade, update, collect garbage, clean boot menu, etc.
#-
#- - `nixy` - UI wizard to manage the system.
#- - `nixy rebuild` - Rebuild the system.
#- - `nixy ...` - ... see the script for more commands.
-{
- pkgs,
- config,
- ...
-}: let
+{ pkgs, config, ... }:
+let
configDirectory = config.var.configDirectory;
- hostname = config.var.hostname;
- nixy =
- pkgs.writeShellScriptBin "nixy"
+ nixy = pkgs.writeShellScriptBin "nixy"
# bash
''
function exec() {
@@ -27,7 +22,7 @@
# "icon;name;command"[]
apps=(
";Rebuild;nixy rebuild"
- ";Upgrade;nixy upgrade"
+ ";Test;nixy test"
";Update;nixy update"
";Collect Garbage;nixy gc"
";Clean Boot Menu;nixy cb"
@@ -54,10 +49,9 @@
[[ $1 == "" ]] && ui
if [[ $1 == "rebuild" ]];then
- cd ${configDirectory} && git add .
- sudo nixos-rebuild switch --flake ${configDirectory}#${hostname}
- elif [[ $1 == "upgrade" ]];then
- sudo nixos-rebuild switch --upgrade --flake '${configDirectory}#${hostname}'
+ cd ${configDirectory} && git add . && sudo nixos-rebuild switch --flake
+ elif [[ $1 == "test" ]];then
+ cd ${configDirectory} && git add . && sudo nixos-rebuild test --flake
elif [[ $1 == "update" ]];then
cd ${configDirectory} && nix flake update
elif [[ $1 == "gc" ]];then
@@ -71,4 +65,4 @@
echo "Unknown argument"
fi
'';
-in {home.packages = [nixy];}
+in { home.packages = [ nixy ]; }
@@ -1,20 +1,15 @@
# - ## Nixy
#-
-#- Nixy is a simple script that I use to manage my NixOS system. It's a simple script that provides a menu to rebuild, upgrade, update, collect garbage, clean boot menu, etc.
+#- Nixy is a simple script that I use to manage my NixOS system. It's a simple script that provides a menu to rebuild, test, update, collect garbage, clean boot menu, etc.
#-
#- - `nixy` - UI wizard to manage the system.